@@ -11,10 +11,11 @@ from subprocess import Popen, PIPE
 from dataclasses import dataclass
 
 
-__version__ = "0.2.14"
+__version__ = "0.2.15"
 
 CFG_DIR = os.path.expanduser("~/.venvipy")
 DB_FILE = os.path.expanduser("~/.venvipy/py-installs")
+ACTIVE_FILE = os.path.expanduser("~/.venvipy/active")
 
 
 
@@ -55,6 +56,15 @@ def ensure_dbfile():
         get_python_installs()
 
 
+def ensure_active_file():
+    """Create the file that holds the selected path to venvs.
+    """
+    ensure_confdir()
+    if not os.path.exists(ACTIVE_FILE):
+        with open(ACTIVE_FILE, "w+") as f:
+            f.write("")
+
+
 def get_python_version(py_path):
     """Return Python version.
     """
@@ -73,9 +83,9 @@ def get_python_installs(relaunching=False):
     Write the found Python versions to `py-installs`. Create
     a new database if `relaunching=True`.
     """
-    ensure_confdir()
     versions = ["3.9", "3.8", "3.7", "3.6", "3.5", "3.4", "3.3"]
     py_info_list = []
+    ensure_confdir()
 
     if not os.path.exists(DB_FILE) or relaunching:
         with open(DB_FILE, "w", newline="") as cf:
@@ -110,8 +120,7 @@ def get_python_installs(relaunching=False):
 
 def add_python(py_path):
     """
-    Write (append) a Python version and it's path to
-    `py-installs` if running in a virtual environment.
+    Write (append) a Python version and its path to `py-installs`.
     """
     ensure_dbfile()
 
@@ -235,19 +244,11 @@ def get_pyvenv_cfg(cfg_file, cfg):
 def get_active_dir_str():
     """Get the default venv directory string from `active` file.
     """
-    active_file = os.path.expanduser("~/.venvipy/active")
-
-    ensure_confdir()
-
-    if os.path.exists(active_file):
-        with open(active_file, "r") as f:
-            active_dir = f.read()
-            return active_dir
-    else:
-        with open(active_file, "w+") as f:
-            active_dir = f.write("")
-            return active_dir
-    return []
+    ensure_active_file()
+    with open(ACTIVE_FILE, "r") as f:
+        active_dir = f.read()
+        return active_dir
+    return ""
 
 
 def get_active_dir():
