@@ -28,12 +28,36 @@ from manage_pip import PipManager
 
 
 logger = logging.getLogger(__name__)
+active_dir = get_data.get_active_dir_str()
 
 
 
-class VenvTable(QTableView):
+class BaseTable(QTableView):
+    """The base table for all tables.
     """
-    List the virtual environments found.
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        self.delete_icon = QIcon(
+            self.style().standardIcon(QStyle.SP_TrashIcon)
+        )
+        self.info_icon = QIcon(
+            self.style().standardIcon(QStyle.SP_FileDialogInfoView)
+        )
+
+    def get_selected_item(self):
+        """
+        Get the item name of the selected row (index 0).
+        """
+        listed_items = self.selectionModel().selectedRows()
+        for index in listed_items:
+            selected_item = index.data()
+            return selected_item
+
+
+
+class VenvTable(BaseTable):
+    """List the virtual environments found.
     """
     started = pyqtSignal()
     finished = pyqtSignal()
@@ -44,9 +68,6 @@ class VenvTable(QTableView):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self.info_icon = QIcon(
-            self.style().standardIcon(QStyle.SP_FileDialogInfoView)
-        )
         self.drive_icon = QIcon(
             self.style().standardIcon(QStyle.SP_DriveHDIcon)
         )
@@ -62,7 +83,6 @@ class VenvTable(QTableView):
 
         self.progress_bar = ProgBarDialog()
         self.console = ConsoleDialog()
-        self.manager = PipManager("", "")
         self.thread = QThread(self)
         self.m_clone_repo_worker = CloningWorker()
 
@@ -81,6 +101,10 @@ class VenvTable(QTableView):
     def contextMenuEvent(self, event):
         context_menu = QMenu(self)
 
+        # pop up only if clicking on a row
+        if self.indexAt(event.pos()).isValid():
+            context_menu.popup(QCursor.pos())
+
         # sub menus
         details_sub_menu = QMenu(
             "Det&ails",
@@ -114,8 +138,7 @@ class VenvTable(QTableView):
         )
 
         install_packages_action = QAction(
-            QIcon.fromTheme("list-add"),
-            "&Install additional packages",
+            "Install &additional packages",
             self,
             statusTip="Install additional packages"
         )
@@ -124,7 +147,6 @@ class VenvTable(QTableView):
         )
 
         install_requires_action = QAction(
-            QIcon.fromTheme("list-add"),
             "Install from &requirements",
             self,
             statusTip="Install packages from requirements"
@@ -134,7 +156,6 @@ class VenvTable(QTableView):
         )
 
         install_local_action = QAction(
-            self.drive_icon,
             "Install &local project",
             self,
             statusTip="Install a local project"
@@ -144,7 +165,6 @@ class VenvTable(QTableView):
         )
 
         install_vsc_action = QAction(
-            QIcon.fromTheme("software-install"),
             "Install from &repository",
             self,
             statusTip="Install from VSC repository"
@@ -164,7 +184,6 @@ class VenvTable(QTableView):
         )
 
         list_packages_action = QAction(
-            self.info_icon,
             "&List installed packages",
             self,
             statusTip="List installed packages"
@@ -173,24 +192,22 @@ class VenvTable(QTableView):
             lambda: self.list_packages(event, style=1)
         )
 
-        freeze_action = QAction(
-            self.info_icon,
+        list_freeze_action = QAction(
             "Show &freeze output",
             self,
             statusTip="List the output of 'pip freeze'"
         )
-        freeze_action.triggered.connect(
-            lambda: self.freeze_output(event, style=2)
+        list_freeze_action.triggered.connect(
+            lambda: self.freeze_packages(event, style=2)
         )
 
-        pipdeptree_action = QAction(
-            self.info_icon,
-            "Show &dependencie tree",
+        list_deptree_action = QAction(
+            "Display &dependency tree",
             self,
             statusTip="List dependencies with 'pipdeptree'"
         )
-        pipdeptree_action.triggered.connect(
-            lambda: self.pipdeptree_output(event, style=3)
+        list_deptree_action.triggered.connect(
+            lambda: self.deptree_packages(event, style=3)
         )
 
         open_venv_dir_action = QAction(
@@ -215,7 +232,7 @@ class VenvTable(QTableView):
 
 
         #]===================================================================[#
-        #] ADD ACTIONS [#====================================================[#
+        #] MENUS [#==========================================================[#
         #]===================================================================[#
 
         context_menu.addAction(upgrade_pip_action)
@@ -227,21 +244,16 @@ class VenvTable(QTableView):
         install_sub_menu.addAction(install_local_action)
         install_sub_menu.addAction(install_vsc_action)
 
-        context_menu.addAction(save_requires_action)
-
         # details sub meun
         context_menu.addMenu(details_sub_menu)
         details_sub_menu.addAction(list_packages_action)
-        details_sub_menu.addAction(freeze_action)
-        details_sub_menu.addAction(pipdeptree_action)
+        details_sub_menu.addAction(list_freeze_action)
+        details_sub_menu.addAction(list_deptree_action)
 
+        context_menu.addAction(save_requires_action)
         context_menu.addAction(open_venv_dir_action)
         context_menu.addAction(delete_venv_action)
 
-        # pop up only if clicking on a row
-        if self.indexAt(event.pos()).isValid():
-            context_menu.popup(QCursor.pos())
-
 
     def valid_version(self, venv_path):
         """Test wether the Python version required is installed.
@@ -305,20 +317,9 @@ class VenvTable(QTableView):
         return False
 
 
-    def get_selected_item(self):
-        """
-        Get the item name of the selected row (index 0).
-        """
-        listed_items = self.selectionModel().selectedRows()
-        for index in listed_items:
-            selected_item = index.data()
-            return selected_item
-
-
     def upgrade_pip(self, event):
         """Run `pip install --upgrade pip` command.
         """
-        active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
 
         if self.has_pip(active_dir, venv):
@@ -349,7 +350,6 @@ class VenvTable(QTableView):
         Install packages from a requirements file into the
         selected environment.
         """
-        active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
 
         if self.has_pip(active_dir, venv):
@@ -381,7 +381,6 @@ class VenvTable(QTableView):
     def install_local(self, event):
         """Install from a local project.
         """
-        active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
 
         if self.has_pip(active_dir, venv):
@@ -412,7 +411,6 @@ class VenvTable(QTableView):
     def install_vsc(self, event):
         """Install from a VSC repository.
         """
-        active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
         venv_bin = os.path.join(active_dir, venv, "bin", "python")
 
@@ -453,7 +451,6 @@ class VenvTable(QTableView):
         """
         Write the requirements of the selected environment to file.
         """
-        active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
         venv_dir = os.path.join(active_dir, venv)
 
@@ -478,9 +475,12 @@ class VenvTable(QTableView):
 
 
     def list_packages(self, event, style):
-        """Open console dialog and list the installed packages.
         """
-        active_dir = get_data.get_active_dir_str()
+        Open console dialog and list the installed packages. The argument
+        `style` controls which style the output should have: `style=1` for
+        `pip list`, `style=2` for `pip freeze` and style=3 for a dependency
+        output via `pipdeptree`.
+        """
         venv = self.get_selected_item()
 
         if self.has_pip(active_dir, venv):
@@ -498,13 +498,13 @@ class VenvTable(QTableView):
                 self.console.console_window.clear()
 
 
-    def freeze_output(self, event, style):
+    def freeze_packages(self, event, style):
         """Print `pip freeze` output to console window.
         """
         self.list_packages(event, style)
 
 
-    def pipdeptree_output(self, event, style):
+    def deptree_packages(self, event, style):
         """
         Test if `pipdeptree` is installed and ask user wether to
         install it if it's not. Then call `self.list_packages()`
@@ -513,7 +513,6 @@ class VenvTable(QTableView):
             "This requires the pipdeptree package\nto be installed.\n\n"
             "Do you want to install it?\n"
         )
-        active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
         pipdeptree_binary = os.path.join(active_dir, venv, "bin", "pipdeptree")
         has_pipdeptree = os.path.exists(pipdeptree_binary)
@@ -548,7 +547,6 @@ class VenvTable(QTableView):
     def open_venv_dir(self, event):
         """Open the selected venv directory.
         """
-        active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
         venv_dir = os.path.join(active_dir, venv)
 
@@ -562,7 +560,6 @@ class VenvTable(QTableView):
         delete from the context menu in venv table.
         """
         venv = self.get_selected_item()
-        active_dir = get_data.get_active_dir_str()
         venv_path = os.path.join(active_dir, venv)
 
         if self.venv_exists(venv_path):
@@ -579,7 +576,7 @@ class VenvTable(QTableView):
 
 
 
-class ResultsTable(VenvTable):
+class ResultsTable(BaseTable):
     """Contains the results from PyPI.
     """
     context_triggered = pyqtSignal()
@@ -632,7 +629,7 @@ class ResultsTable(VenvTable):
 
 
 
-class InterpreterTable(VenvTable):
+class InterpreterTable(BaseTable):
     """
     List the Python installs found.
     """
@@ -641,9 +638,6 @@ class InterpreterTable(VenvTable):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self.delete_icon = QIcon(
-            self.style().standardIcon(QStyle.SP_TrashIcon)
-        )
 
     def contextMenuEvent(self, event):
         context_menu = QMenu(self)
