@@ -6,6 +6,7 @@ import sys
 import os
 import csv
 import getopt
+import logging
 from pathlib import Path
 
 # need to set the correct cwd
@@ -34,7 +35,6 @@ from PyQt5.QtWidgets import (
     QPushButton,
     QSpacerItem,
     QSizePolicy,
-    QTableView,
     QMenuBar,
     QMenu,
     QStatusBar,
@@ -49,7 +49,12 @@ import venvipy_rc  # pylint: disable=unused-import
 import get_data
 import wizard
 from dialogs import InfoAboutVenviPy
-from tables import VenvTable
+from tables import VenvTable, InterpreterTable
+
+
+LOG_FORMAT = "[%(levelname)s] - { %(name)s }: %(message)s"
+logging.basicConfig(level=logging.INFO, format=LOG_FORMAT)
+logger = logging.getLogger()
 
 
 
@@ -116,10 +121,10 @@ class MainWindow(QMainWindow):
         self.info_about_venvipy = InfoAboutVenviPy()
         self.venv_wizard = wizard.VenvWizard()
 
-        # refresh venv table when wizard closed
+        # refresh venv table on wizard close
         self.venv_wizard.refresh.connect(self.pop_venv_table)
 
-        # refresh interpreter table when selecting a custom one in wizard menu
+        # refresh interpreter table if 'py-installs' changes
         self.venv_wizard.update_table.connect(self.pop_interpreter_table)
 
 
@@ -257,12 +262,13 @@ class MainWindow(QMainWindow):
         )
 
         # interpreter table
-        self.interpreter_table = QTableView(
+        self.interpreter_table = InterpreterTable(
             centralwidget,
             selectionBehavior=QAbstractItemView.SelectRows,
             editTriggers=QAbstractItemView.NoEditTriggers,
             alternatingRowColors=True,
-            sortingEnabled=True
+            sortingEnabled=True,
+            drop_item=self.pop_interpreter_table
         )
 
         # hide vertical header
@@ -448,28 +454,24 @@ class MainWindow(QMainWindow):
         )
 
         # check if any Python is installed
-        csv_file = os.path.expanduser("~/.venvipy/py-installs")
-        if os.path.isfile(csv_file):
-            with open(csv_file, newline="") as cf:
-                reader = csv.DictReader(cf, delimiter=",")
-                if reader is None:
-                    self.launching_without_python()
-
-
-    def info_about_qt(self):
-        """Open the "About Qt" dialog.
-        """
-        QMessageBox.aboutQt(self)
+        if os.path.exists(get_data.DB_FILE):
+            with open(get_data.DB_FILE, "r") as f:
+                lines = f.readlines()
+            if len(lines) < 2:
+                self.launching_without_python()
 
 
     def launching_without_python(self):
-        print("[WARNING]: No suitable Python installation found!")
-        self.enable_features(False)
+        """If no Python was found run with features disabled.
+        """
+        logger.warning("No suitable Python installation found")
         self.msg_box.addButton("&Select", QMessageBox.AcceptRole)
         self.msg_box.addButton("&Continue", QMessageBox.RejectRole)
         if self.msg_box.exec_() == QMessageBox.AcceptRole:
             # let user specify path to an interpreter
             self.add_interpreter()
+        else:
+            self.enable_features(False)
 
 
     def center(self):
@@ -489,6 +491,12 @@ class MainWindow(QMainWindow):
         self.close()
 
 
+    def info_about_qt(self):
+        """Open the "About Qt" dialog.
+        """
+        QMessageBox.aboutQt(self)
+
+
     def add_interpreter(self):
         """Add a custom interpreter.
         """
@@ -497,30 +505,35 @@ class MainWindow(QMainWindow):
 
 
     def enable_features(self, state):
+        """Enable or disable features.
+        """
+        self.venv_table.setEnabled(state)
         #self.search_pypi_button.setEnabled(state)
         #self.action_search_pypi.setEnabled(state)
-        self.venv_table.setEnabled(state)
 
 
     @pyqtSlot()
     def pop_interpreter_table(self):
         """Populate the interpreter table view.
         """
-        csv_file = os.path.expanduser("~/.venvipy/py-installs")
+        get_data.ensure_dbfile()
 
-        if os.path.isfile(csv_file):
-            info = []
-            with open(csv_file, newline="") as cf:
-                reader = csv.DictReader(cf, delimiter=",")
-                self.model_interpreter_table.setRowCount(0)
-                for info in reader:
-                    self.model_interpreter_table.insertRow(0)
-                    for i, text in enumerate(
-                            (info["PYTHON_VERSION"], info["PYTHON_PATH"])
-                        ):
-                        self.model_interpreter_table.setItem(
-                            0, i, QStandardItem(text)
-                        )
+        with open(get_data.DB_FILE, newline="") as cf:
+            reader = csv.DictReader(cf, delimiter=",")
+            self.model_interpreter_table.setRowCount(0)
+            for info in reader:
+                self.model_interpreter_table.insertRow(0)
+                for i, text in enumerate(
+                        (info["PYTHON_VERSION"], info["PYTHON_PATH"])
+                    ):
+                    self.model_interpreter_table.setItem(
+                        0, i, QStandardItem(text)
+                    )
+
+        # clear combo box content and call pop_combo_box()
+        self.venv_wizard.basic_settings.interpreter_combo_box.clear()
+        self.venv_wizard.basic_settings.interpreter_combo_box.addItem("---")
+        self.venv_wizard.basic_settings.pop_combo_box()
 
 
     def pop_venv_table(self):
@@ -631,7 +644,7 @@ def main():
     os.system("clear")
 
     main_window = MainWindow()
-    get_data.get_python_installs()
+    get_data.get_python_installs(True)
     main_window.pop_interpreter_table()
     main_window.venv_wizard.basic_settings.pop_combo_box()
     main_window.pop_venv_table()
